# NaGausspy
![](https://gitlab.com/nafomat/nagausspy/badges/master/coverage.svg) ![](https://gitlab.com/nafomat/nagausspy/badges/master/pipeline.svg)

## Installation
the easiest way of installation is using Pypi with pip:
`pip install nagausspy`

## TODO

- Add more tests
- Improve optimization step reading
- Simpler and clear documentation